
##############################################################################
# neighb.xy is a function to profile the two False Positive Rates as parameters  
# sp12 is a vector of the two False Positive Rates
# nx is the sample size of X
# x is a non diseased sample
# ny is the sample size of Y
# y is a diseased sample
# true is the tested Partial AUC
##############################################################################

neighb.xy <- function( sp12 = vector("numeric",2), x, y, true, tol=.001, eps){

  nx <- length(x)
  ny <- length(y)
  
  if(sp12[1] >= sp12[2] )
    stop("the first sample quantile has to be smaller than the second")
  
  #sortedx <- x[order(x)]
  
  #cx<-cumsum(rep(1/nx, nx))
  
  sortx_w <- myWdataclean2(z=x)
  
  sortedx <- sortx_w$value
  
  cx<- cumsum(sortx_w$weight/nx)
  
  #idex1 <- max(which(cx <= 1- sp12[2] ))
  #idex2 <- max(which(cx <= 1- sp12[1] ))
  idex1 <- ifelse(sp12[2] < 1, max(which(cx <=1- sp12[2] )), 1)
  idex2 <- max(which(cx <=1- sp12[1] ))
  
  abs <- data.frame(x1=idex1, x2=idex2)
  
  best <- eltest2step(ab=c(sortedx[idex1], sortedx[idex2]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps)
  
  neg2.llr <- data.frame(value=best)
  ite <- TRUE
  while (ite==TRUE) {  
    neib1 <- c((idex1-1), idex2)
    if (idex1-1 > 0) {
      if ((!any(abs[,1]==neib1[1])) || (!any(which(neib1[1]==abs[,1]) 
                                             %in% which(neib1[2]==abs[,2])))){
        abs <- rbind(abs, neib1)
        neg2.llr <- rbind(neg2.llr, eltest2step(ab=c(sortedx[idex1-1], sortedx[idex2]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    neib2 <- c(idex1, (idex2-1))
    if (idex2-1 > idex1) {
      if ((!any(abs[,2]==neib2[2]))||(!any(which(neib2[1]==abs[,1]) %in% which(neib2[2]==abs[,2])))){
        abs <- rbind(abs, neib2)
        neg2.llr <- rbind(neg2.llr, eltest2step(ab=c(sortedx[idex1], sortedx[idex2-1]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    neib3 <- c((idex1+1), idex2)
    if (idex1+1 < idex2) {
      if ((!any(abs[,1]==neib3[1]))||(!any(which(neib3[1]==abs[, 1]) %in% which(neib3[2]==abs[,2])))){
        abs <- rbind(abs, neib3)
        neg2.llr <- rbind(neg2.llr, eltest2step(ab=c(sortedx[idex1 + 1], sortedx[idex2]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol,  eps=eps))
      }  
    }
    
    neib4 <- c(idex1, (idex2 +1))
    if (idex2+1 < nx) {
      if ((!any(abs[,2]==neib4[2]))||(!any(which(neib4[1]==abs[, 1]) %in% which(neib4[2]==abs[,2])))){
        abs <- rbind(abs, neib4)
        neg2.llr <- rbind(neg2.llr, eltest2step(ab=c(sortedx[idex1], sortedx[idex2 + 1]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    neib5 <- c((idex1-1), (idex2-1))
    if ((idex1-1 > 0) & (idex2-1 > idex1)){
      if (!any(which(neib5[1]==abs[, 1]) %in% which(neib5[2]==abs[,2]))){
        abs <- rbind(abs, neib5)
        neg2.llr <- rbind(neg2.llr,eltest2step(ab=c(sortedx[idex1 -1], sortedx[idex2 - 1]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    neib6 <- c((idex1-1), (idex2+1))
    if ((idex1-1 > 0) & (idex2+1 < nx)){
      if (!any(which(neib6[1]==abs[, 1]) %in% which(neib6[2]==abs[,2]))){
        abs <- rbind(abs, neib6)
        neg2.llr <- rbind(neg2.llr, eltest2step(ab=c(sortedx[idex1 -1], sortedx[idex2 +1]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    neib7 <- c((idex1 + 1), idex2 - 1)
    
    if (idex1+1 < idex2-1) {
      if (!any(which(neib7[1]==abs[, 1]) %in% which(neib7[2]==abs[,2]))){
        abs <- rbind(abs, neib7)
        neg2.llr <- rbind(neg2.llr,eltest2step(ab=c(sortedx[idex1 + 1], sortedx[idex2 - 1]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    neib8 <- c((idex1 +1), (idex2 + 1))
    if ((idex1+1 < idex2) & (idex2+1 < nx)){
      if (!any(which(neib8[1]==abs[, 1]) %in% which(neib8[2]==abs[,2]))){
        abs <- rbind(abs, neib8)
        neg2.llr <- rbind(neg2.llr, eltest2step(ab=c(sortedx[idex1 +1], sortedx[idex2 + 1]), x=x, y=y, p1=sp12[1], p2=sp12[2], true, tol, eps=eps))
      }
    }
    
    if (min(neg2.llr)==best){
      
      idex1 <- abs[which(neg2.llr==best), 1]
      idex2 <- abs[which(neg2.llr==best), 2]
            
     return(list('-2LLR'=best, Pval = 1 - pchisq(best, df=1)))
      
     # return("-2LLR" = best)
      
      ite <- FALSE
    }  
    else {
      best=min(neg2.llr)
      idex1 <- abs[which(neg2.llr==best), 1]
      idex2 <- abs[which(neg2.llr==best), 2]
      ite <- TRUE
    }
  }
}


