\name{eltest}
\alias{eltest}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Empirical likelihood test for percentile at p1 and p2, and trimmed mean at (p1, p2)
}
\description{
Compute the empirical likelihood ratio test of three parameters: percentiles at p1 and p2, and trimmed mean at (p1, p2)
}
\usage{
eltest(ab = vector("numeric", 2), x.sample, mu, eps)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ab}{
a vector of two elements for the percentiles at p1 and p2
}
  \item{x.sample}{
a random sample
}
  \item{mu}{
the null hypothesis vector with three elements (p1, p2, \eqn{\mu_T})
}
  \item{eps}{
a smoothing parameter
}
}
\details{
If mu is far away from the true value vector, "-2LLR" may be positive infinite. 
}
\value{
\item{"-2LLR"}{the -2 loglikelihood ratio; approximate chi square distribution with a degree of freedom 3 under \eqn{H_0}}
}
\references{
Mai Zhou. and Yifan Yang (for C part), emplik: Empirical likelihood ratio for censored/truncated data, 2014, R package version 0.9-9-6, http://CRAN.R-project.org/package=emplik
}
\author{
Yumin Zhao
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{

set.seed(123)

nsize <- 50
p1<- 0.21
p2<- 0.79

q1 <- qnorm(p1)
q2 <- qnorm(p2)

rp_trim <- function(x){
  y <- x*dnorm(x)
  y
}

omu_trim <- integrate(rp_trim, lower=q1, upper=q2)$value
mu_trim <- c(p1, p2, omu_trim)

x <- rnorm(nsize)
 
eltest(c(q1, q2), x, mu=mu_trim, eps=1/nsize)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
